@@ -7,28 +7,26 @@ typedef struct Opaque Opaque;
 
 typedef struct Option_____Opaque Option_____Opaque;
 
-typedef struct Option_______c_void Option_______c_void;
-
 typedef struct {
   const Opaque *x;
   Opaque *y;
   void (*z)(void);
-  Option_______c_void *zz;
+  void (**zz)(void);
 } Foo;
 
 typedef union {
   const Opaque *x;
   Opaque *y;
   void (*z)(void);
-  Option_______c_void *zz;
+  void (**zz)(void);
 } Bar;
 
 #ifdef __cplusplus
 extern "C" {
 #endif // __cplusplus
 
-void root(const Opaque *a, Opaque *b, Foo c, Bar d, Option_____Opaque *e);
+void root(const Opaque *a, Opaque *b, Foo c, Bar d, Option_____Opaque *e, void (*f)(const Opaque*));
 
 #ifdef __cplusplus
-} // extern "C"
-#endif // __cplusplus
+}  // extern "C"
+#endif  // __cplusplus
